from ConfigParser import ConfigParser

config = ConfigParser()
config.read('/etc/dofler/dofler.conf')